==> ansible_7.7.0+dfsg.orig.tar.xz: ansible-7.7.0/ansible_collections/t_systems_mms/icinga_director/plugins/modules/icinga_serviceset.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2020 T-Systems Multimedia Solutions GmbH
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
#
# This module is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this software.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import, division, print_function

__metaclass__ = type

DOCUMENTATION = """
---
module: icinga_serviceset
short_description: Manage servicesets in Icinga2
description:
   - Add or remove a serviceset to Icinga2 through the director API.
author: Heiko Neblung (@HeikoNeblung)
extends_documentation_fragment:
  - ansible.builtin.url
  - t_systems_mms.icinga_director.common_options
version_added: '1.29.0'
notes:
  - This module supports check mode.
options:
  append:
    description:
      - Do not overwrite the whole object but instead append the defined properties.
      - Note - Appending to existing vars, imports or any other list/dict is not possible. You have to overwrite the complete list/dict.
      - Note - Variables that are set by default will also be applied, even if not set.
    type: bool
    choices: [true, false]
  assign_filter:
    description:
      - This allows you to configure an assignment filter.
      - Please feel free to combine as many nested operators as you want.
    type: str
  description:
    description:
      - A meaningful description explaining your users what to expect when assigning this set of services.
    type: str
  object_name:
    description:
      - Icinga object name for this serviceset.
    aliases: ['name']
    required: true
    type: str
  state:
    description:
      - Apply feature state.
    choices: [ "present", "absent" ]
    default: present
    type: str
"""

EXAMPLES = """
- name: Create serviceset
  t_systems_mms.icinga_director.icinga_serviceset:
    state: present
    url: "{{ icinga_url }}"
    url_username: "{{ icinga_user }}"
    url_password: "{{ icinga_pass }}"
    object_name: "foo_serviceset"
    assign_filter: 'host.name="foohost"'
    description: "foo description"

- name: Update serviceset
  t_systems_mms.icinga_director.icinga_serviceset:
    state: present
    url: "{{ icinga_url }}"
    url_username: "{{ icinga_user }}"
    url_password: "{{ icinga_pass }}"
    object_name: "foo_serviceset"
    assign_filter: 'host.name="foohost2"'
    append: true
"""

RETURN = r""" # """

from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.urls import url_argument_spec
from ansible_collections.t_systems_mms.icinga_director.plugins.module_utils.icinga import (
    Icinga2APIObject,
)


# ===========================================
# Module execution.
#
def main():
    # use the predefined argument spec for url
    argument_spec = url_argument_spec()
    # add our own arguments
    argument_spec.update(
        append=dict(type="bool", choices=[True, False]),
        assign_filter=dict(required=False),
        description=dict(required=False),
        object_name=dict(required=True, aliases=["name"]),
        state=dict(default="present", choices=["absent", "present"]),
        url=dict(required=True),
    )

    # Define the main module
    module = AnsibleModule(
        argument_spec=argument_spec, supports_check_mode=True
    )

    data_keys = [
        "assign_filter",
        "description",
        "object_name",
    ]

    data = {}

    if module.params["append"]:
        for k in data_keys:
            if module.params[k]:
                data[k] = module.params[k]
    else:
        for k in data_keys:
            data[k] = module.params[k]

    data["object_type"] = "template"

    icinga_object = Icinga2APIObject(
        module=module, path="/serviceSet", data=data
    )

    changed, diff = icinga_object.update(module.params["state"])
    module.exit_json(
        changed=changed,
        diff=diff,
    )


# import module snippets
if __name__ == "__main__":
    main()

==> ansible_9.2.0+dfsg.orig.tar.xz: ansible-9.2.0/ansible_collections/t_systems_mms/icinga_director/plugins/modules/icinga_serviceset.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2020 T-Systems Multimedia Solutions GmbH
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
#
# This module is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this software.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import absolute_import, division, print_function

__metaclass__ = type

DOCUMENTATION = """
---
module: icinga_serviceset
short_description: Manage servicesets in Icinga2
description:
   - Add or remove a serviceset to Icinga2 through the director API.
author: Heiko Neblung (@HeikoNeblung)
extends_documentation_fragment:
  - ansible.builtin.url
  - t_systems_mms.icinga_director.common_options
version_added: '1.29.0'
notes:
  - This module supports check mode.
deprecated:
  why: moved collection to new organisation telekom_mms
  removed_in: 3.0.0
  alternative: telekom_mms.icinga_director.icinga_serviceset
options:
  append:
    description:
      - Do not overwrite the whole object but instead append the defined properties.
      - Note - Appending to existing vars, imports or any other list/dict is not possible. You have to overwrite the complete list/dict.
      - Note - Variables that are set by default will also be applied, even if not set.
    type: bool
    choices: [true, false]
  assign_filter:
    description:
      - This allows you to configure an assignment filter.
      - Please feel free to combine as many nested operators as you want.
    type: str
  description:
    description:
      - A meaningful description explaining your users what to expect when assigning this set of services.
    type: str
  object_name:
    description:
      - Icinga object name for this serviceset.
    aliases: ['name']
    required: true
    type: str
  state:
    description:
      - Apply feature state.
    choices: [ "present", "absent" ]
    default: present
    type: str
"""

EXAMPLES = """
- name: Create serviceset
  t_systems_mms.icinga_director.icinga_serviceset:
    state: present
    url: "{{ icinga_url }}"
    url_username: "{{ icinga_user }}"
    url_password: "{{ icinga_pass }}"
    object_name: "foo_serviceset"
    assign_filter: 'host.name="foohost"'
    description: "foo description"

- name: Update serviceset
  t_systems_mms.icinga_director.icinga_serviceset:
    state: present
    url: "{{ icinga_url }}"
    url_username: "{{ icinga_user }}"
    url_password: "{{ icinga_pass }}"
    object_name: "foo_serviceset"
    assign_filter: 'host.name="foohost2"'
    append: true
"""

RETURN = r""" # """

from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.urls import url_argument_spec
from ansible_collections.t_systems_mms.icinga_director.plugins.module_utils.icinga import (
    Icinga2APIObject,
)


# ===========================================
# Module execution.
#
def main():
    # use the predefined argument spec for url
    argument_spec = url_argument_spec()
    # add our own arguments
    argument_spec.update(
        append=dict(type="bool", choices=[True, False]),
        assign_filter=dict(required=False),
        description=dict(required=False),
        object_name=dict(required=True, aliases=["name"]),
        state=dict(default="present", choices=["absent", "present"]),
        url=dict(required=True),
    )

    # Define the main module
    module = AnsibleModule(
        argument_spec=argument_spec, supports_check_mode=True
    )

    data_keys = [
        "assign_filter",
        "description",
        "object_name",
    ]

    data = {}

    if module.params["append"]:
        for k in data_keys:
            if module.params[k]:
                data[k] = module.params[k]
    else:
        for k in data_keys:
            data[k] = module.params[k]

    data["object_type"] = "template"

    icinga_object = Icinga2APIObject(
        module=module, path="/serviceSet", data=data
    )

    changed, diff = icinga_object.update(module.params["state"])
    module.exit_json(
        changed=changed,
        diff=diff,
    )


# import module snippets
if __name__ == "__main__":
    main()
